@@ -190,9 +190,13 @@ class Workspace(object):
 
   def _create_wcache(self):
     self._unpickle_wcache_from_disk()
-    if not self._wcache or self._options['automatic_refresh']:
+    if self._wcache_is_empty or self._options['automatic_refresh']:
       self.refresh()
 
+  
+  def _wcache_is_empty(self):
+    return not self._wcache or not self._wcache['records']
+
 
   def _flush_wcache(self):
     self._pickle_wcache_to_disk()
